added stylesheet() to html helper
diff --git a/system/helpers/html_helper.php b/system/helpers/html_helper.php
index d887be6..660d867 100644
--- a/system/helpers/html_helper.php
+++ b/system/helpers/html_helper.php
@@ -230,8 +230,11 @@
* Generates link to a CSS file
*
* @access public
* @param mixed stylesheet name(s)
* @param string media type
* @param boolean should index_page be added to the css path
* @return string
*/
@@ -304,6 +307,25 @@
// ------------------------------------------------------------------------
/**
+ * Stylesheet
+ *
+ * Generates a <link /> to a CSS
+ *
+ * @access public
+ * @param array
+ * @return string
+ */
+if (! function_exists('stylesheet'))
+{
+ function stylesheet($href = '', $rel = 'stylesheet', $title = '', $media = 'screen')
+ {
+ return link($href, $rel, 'text/css', $title, $media);
+ }
+}
+
+// ------------------------------------------------------------------------
+
+/**
* Generates meta tags from an array of key/values
*
* @access public
@@ -230,8 +230,11 @@
*
* @access public
- * @param mixed stylesheet name(s)
- * @param string media type
+ * @param mixed stylesheet hrefs or an array
+ * @param string rel
+ * @param string type
+ * @param string title
+ * @param string media
* @param boolean should index_page be added to the css path
* @return string